/* $Id: BooleanDocument.java,v 1.2 2007/10/24 09:10:39 nito Exp $
 * 
 * Copyright (c)ARGO 21, Corporation. 2005, 2006.  All rights reserved.
 * 
 * This file is part of Nautica Workflow.
 * 
 *  Nautica Workflow is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 * 
 *  Nautica Workflow is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 * 
 *  You should have received a copy of the GNU General Public License
 *  along with Nautica Workflow; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *  
 */
package jp.co.argo21.nautica.commons.swing;

import javax.swing.text.*;

/**
 * 真理値入力用フィールドのための制御を行う。
 * このドキュメントを使うと、`t'をキー入力すると、`true'を表示し、
 * `f'をキー入力すると、`false'を表示する。
 * JTextFIeldに対して、設定を行うことができる。
 * 
 * <pre>
 * JTextField f = new JTextField();
 * f.setDocument(new BooleanDocument());
 * </pre>
 *
 * @author  Norihiro Itoh(ARGO 21 Corp.)
 * @version $Revision: 1.2 $
 * @since   Nautica Workflow 1.0
 */
public class BooleanDocument extends PlainDocument
{
	/** シリアルバージョンID */
	private static final long serialVersionUID = 1L;

	private static final String TRUE  = "true";
	private static final String FALSE = "false";

	/**
	 * 真理値入力制限用ドキュメントオブジェクトを生成する。
	 */
	public BooleanDocument()
	{
	}

	/**
	 * 文字列挿入時の制御を行う。
	 *
	 * @param offset 挿入位置
	 * @param s      挿入文字列
	 * @param a      属性値
	 * @throws BadLocationException 指定された挿入の位置が、ドキュメント内の有効な位置ではない場合
	 */
	public void insertString(int offset, String s, AttributeSet a) throws BadLocationException
	{
		if (s == null) return;
		
		String v = null;
		char[] chars = s.toCharArray();
		int max = chars.length;
		for (int i = 0; i < max; i++) {
			char c = chars[i];
			switch (c) {
				case 'T':
				case 't':
					v = TRUE;
					break;
				case 'F':
				case 'f':
					v = FALSE;
					break;
			}
		}
		if (v == null) return;

		this.remove(0, getLength());
		super.insertString(0, v, a);
	}
}
