/* $Id: DialogUtilities.java,v 1.2 2007/10/24 09:10:39 nito Exp $
 * 
 * Copyright (c)ARGO 21, Corporation. 2005, 2006.  All rights reserved.
 * 
 * This file is part of Nautica Workflow.
 * 
 *  Nautica Workflow is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 * 
 *  Nautica Workflow is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 * 
 *  You should have received a copy of the GNU General Public License
 *  along with Nautica Workflow; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *  
 */
package jp.co.argo21.nautica.commons.swing;

import java.util.MissingResourceException;
import java.util.ResourceBundle;

import javax.swing.*;

/**
 * 基本ダイアログの簡易表示用のユーティリティ
 *
 * @author  Norihiro Itoh(ARGO 21 Corp.)
 * @version $Revision: 1.2 $
 * @since   Nautica Workflow 1.0
 */
public final class DialogUtilities
{
	/** バンドルパス */
	private static final String path = "jp.co.argo21.nautica.commons.swing.resources.commons-swing";

	/** リソースバンドル */
	private static ResourceBundle resources;

	static
	{
		try {
			resources = ResourceBundle.getBundle(path);
		} catch (MissingResourceException ex) {
			ex.printStackTrace();
		}
	}

	/**
	 * 指定された文字列を、情報パネルとして表示する。
	 *
	 * @param	message 文字列
	 */
	public static final void showInfo(String message)
	{
		JOptionPane.showMessageDialog(
				null,
				message,
				resources.getString("DialogUtilities.info"),
				JOptionPane.INFORMATION_MESSAGE
			);
	}

	/**
	 * 指定された文字列を、エラーパネルとして表示する。
	 *
	 * @param	message 文字列
	 */
	public static final void showError(String message)
	{
		JOptionPane.showMessageDialog(
				null,
				message,
		        resources.getString("DialogUtilities.error"),
				JOptionPane.ERROR_MESSAGE
			);
	}

	/**
	 * 指定された文字列を、警告パネルとして表示する。
	 *
	 * @param	message 文字列
	 */
	public static final void showWarning(String message)
	{
		JOptionPane.showMessageDialog(
				null,
				message,
				resources.getString("DialogUtilities.warning"),
				JOptionPane.WARNING_MESSAGE
			);
	}

	/**
	 * 指定された文字列を、OK_CANCEL_OPTION付確認パネルとして表示する。
	 *
	 * @param	message 文字列
	 */
	public static final int showOkCancelConfirm(String message)
	{
		return JOptionPane.showConfirmDialog(
				null,
				message,
				resources.getString("DialogUtilities.confirm"),
				JOptionPane.OK_CANCEL_OPTION,
				JOptionPane.QUESTION_MESSAGE
			);
	}

	/**
	 * 指定された文字列を、YES_NO_OPTION付確認パネルとして表示する。
	 *
	 * @param	message 文字列
	 */
	public static final int showYesNoConfirm(String message)
	{
		return JOptionPane.showConfirmDialog(
				null,
				message,
				resources.getString("DialogUtilities.confirm"),
				JOptionPane.YES_NO_OPTION,
				JOptionPane.QUESTION_MESSAGE
			);
	}

	/**
	 * 指定された文字列を、YES_NO_CANCEL_OPTION付確認パネルとして表示する。
	 *
	 * @param	message 文字列
	 */
	public static final int showYesNoCanelConfirm(String message)
	{
		return JOptionPane.showConfirmDialog(
				null,
				message,
				resources.getString("DialogUtilities.confirm"),
				JOptionPane.YES_NO_CANCEL_OPTION,
				JOptionPane.QUESTION_MESSAGE
			);
	}
}
