/* $Id: VersionFrame.java,v 1.1 2007/10/24 09:10:39 nito Exp $
 * 
 * Copyright (c)ARGO 21, Corporation. 2005, 2006.  All rights reserved.
 * 
 * This file is part of Nautica Workflow.
 * 
 *  Nautica Workflow is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 * 
 *  Nautica Workflow is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 * 
 *  You should have received a copy of the GNU General Public License
 *  along with Nautica Workflow; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *  
 */
package jp.co.argo21.nautica.commons.swing;

import java.awt.*;

import javax.swing.*;

/**
 * 汎用のバージョン表示画面である。画面の表示位置は、スクリーン中央に配置され、
 * 画面の大きさはロードされるロゴイメージのサイズになる。
 * 画面下部にはバージョンと著作権表示が表示されるので、
 * 使用するイメージと文字色によっては見づらくなる場合が考えられる。
 *
 * @author  Norihiro Itoh(ARGO 21 Corp.)
 * @version $Revision: 1.1 $
 * @since   Nautica Workflow 1.0
 */
public final class VersionFrame extends JInternalFrame
{
	/** シリアルバージョンID */
	private static final long serialVersionUID = 1L;

	/**
	 * バージョン表示画面を生成する。
	 *
	 * @param path      製品ロゴイメージリソースパス名
	 * @param copyright 著作権表示
	 * @param version   バージョン
	 * @param color     文字色
	 */
	public VersionFrame(String path, String copyright, String version, Color color)
	{
		super("About...", false, true);
		this.setLayer(JLayeredPane.POPUP_LAYER);

		VersionPanel panel = new VersionPanel(path, copyright, version, color);
		setContentPane(panel);
		pack();
	}

	/**
	 * バージョン表示画面を中央に表示する。
	 */
	public void show()
	{
		Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize();
		Dimension size = getSize();
		setBounds(
			(screenSize.width - size.width) / 2,
			screenSize.height / 4,
			size.width,
			size.height
			);
		super.show();
	}
}
