/* $Id: VersionPanel.java,v 1.2 2007/10/24 09:10:39 nito Exp $
 * 
 * Copyright (c)ARGO 21, Corporation. 2005, 2006.  All rights reserved.
 * 
 * This file is part of Nautica Workflow.
 * 
 *  Nautica Workflow is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 * 
 *  Nautica Workflow is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 * 
 *  You should have received a copy of the GNU General Public License
 *  along with Nautica Workflow; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *  
 */
package jp.co.argo21.nautica.commons.swing;

import java.awt.*;
import javax.swing.JPanel;

/**
 * バージョン表示用パネルである。
 *
 * @author  Norihiro Itoh(ARGO 21 Corp.)
 * @version $Revision: 1.2 $
 * @since   Nautica Workflow 1.0
 */
public class VersionPanel extends JPanel
{
	/** シリアルバージョンID */
	private static final long serialVersionUID = 1L;

	/** 製品ロゴイメージ */
	private Image logo;

	/** 著作権表示 */
	private String copyright = "";

	/** バージョン表示 */
	private String version = "";

	/** 文字色 */
	private Color color = Color.black;

	/**
	 * バージョン表示用エリアを生成する。
	 * 
	 * @param path      製品ロゴイメージリソースパス名
	 * @param version   バージョン
	 * @param copyright 著作権表示
	 * @param color     文字色
	 */
	public VersionPanel(String path, String version, String copyright, Color color)
	{
		super();

		this.version = ((version != null)? version : "");
		this.copyright = ((copyright != null)? copyright : "");
		this.color = ((color!= null)? color : Color.black);

		try {
			logo = Toolkit.getDefaultToolkit().getImage(getClass().getResource(path));

			// イメージが完全にロードされるまで待つ。
			MediaTracker tracker = new MediaTracker(this);
			tracker.addImage(logo, 0);
			tracker.waitForID(0);

			// 表示エリアをロードしたイメージのサイズにあわせる。
			Dimension size =
				new Dimension(logo.getWidth(this), logo.getHeight(this));
			this.setPreferredSize(size);
		} catch (Exception ex) {
			logo = null;
			this.setPreferredSize(new Dimension(350, 250));
		}
	}

	/**
	 * バージョン表示を描画する。
	 *
	 * @param	g	描画対象グラフィックス
	 */
	public void paintComponent(Graphics g)
	{
		//背景となるロゴイメージを描画する。
		if (logo != null) g.drawImage(logo, 0, 0, this);

		Dimension size = this.getSize();
		Font f = new Font("SansSerif", Font.BOLD, 12);
		FontMetrics metrics = g.getFontMetrics(f);
		int height = metrics.getHeight();
		int descent = metrics.getDescent();

		g.setColor(color);
		g.setFont(f);

		//バージョンを描画する。
		if (version != null) {
			int width = metrics.stringWidth(version);
			int dx = (size.width - width) / 2;
			int dy = size.height - (height + descent + 20);
			g.drawString(version, dx, dy);
		}

		//コピーライトを描画する。
		if (copyright != null) {
			int width = metrics.stringWidth(copyright);
			int dx = (size.width - width) / 2;
			int dy = size.height - (descent + 10);
			g.drawString(copyright, dx, dy);
		}
	}
}
